GromacsWrapper — a Python framework for Gromacs — GromacsWrapper 0.6.1 documentation

# GromacsWrapper — a Python framework for Gromacs

Release: | 0.6.1
Date: | September 16, 2016

GromacsWrapper is a Python package that wraps system calls to Gromacs tools into thin classes. This allows for fairly seamless integration of the gromacs tools into Python scripts. This is generally superior to shell scripts because of Python’s better error handling and superior data structures. It also allows for modularization and code re-use. In addition, commands, warnings and errors are logged to a file so that there exists a complete history of what has been done.

See INSTALL for download and installation instructions. Documentation is primarily provided through the Python doc strings (from which most of the online documentation is generated).

The source code itself is available in the GromacsWrapper git repository.

Warning

Please be aware that this is alpha software that most definitely contains bugs. The API is not stable yet and can change between releases.

It is your responsibility to ensure that you are running simulations with sensible parameters.

The package and the documentation are still in flux and any feedback, bug reports, suggestions and contributions are very welcome. See the package README: GromacsWrapper for contact details.

See also

Other approaches to interfacing Python and Gromacs are listed under Alternatives to GromacsWrapper.

## Contents

- Installation
  - README: GromacsWrapper
  - INSTALL
- Configuration
  - Basic options
  - More options
- GromacsWrapper package
  - `gromacs` – GromacsWrapper Package Overview
  - Gromacs core modules
  - Gromacs building blocks
- Analysis
  - Analysis core modules
  - Support modules
  - Analysis plugins
- Auxiliary modules
  - `numkit` — Numerical analysis toolkit
  - `vmd` — Remote Tcl commands in VMD
  - `staging` — Staging of input/output files on a queuing system
- Alternatives to GromacsWrapper

## Indices and tables

- Index
- Module Index
- Search Page